pub struct TraceContext {
pub trace_id: String,
pub span_id: String,
pub parent_span_id: Option<String>,
pub originating_core_id: CoreId,
pub current_core_id: CoreId,
pub tenant_id: TenantId,
pub command_id: Option<String>,
}Expand description
Correlation context propagated across distributed Runtime boundaries.
Fields
trace_id: StringEnd-to-end trace identity.
span_id: StringCurrent span identity.
parent_span_id: Option<String>Parent span identity, when this is a child span.
originating_core_id: CoreIdCore that originated the trace.
current_core_id: CoreIdCore currently handling the operation.
tenant_id: TenantIdTenant isolation boundary.
command_id: Option<String>Optional command identity associated with the trace.
Implementations
Sourceimpl TraceContext
impl TraceContext
Sourcepub fn new(
trace_id: impl Into<String>,
span_id: impl Into<String>,
originating_core_id: CoreId,
current_core_id: CoreId,
tenant_id: TenantId,
) -> Result<TraceContext, RuntimeError>
pub fn new( trace_id: impl Into<String>, span_id: impl Into<String>, originating_core_id: CoreId, current_core_id: CoreId, tenant_id: TenantId, ) -> Result<TraceContext, RuntimeError>
Creates and validates a root trace context.
Sourcepub fn with_command_id(
self,
command_id: impl Into<String>,
) -> Result<TraceContext, RuntimeError>
pub fn with_command_id( self, command_id: impl Into<String>, ) -> Result<TraceContext, RuntimeError>
Associates a validated command identity with this context.
Sourcepub fn child_span(
&self,
span_id: impl Into<String>,
current_core_id: CoreId,
) -> Result<TraceContext, RuntimeError>
pub fn child_span( &self, span_id: impl Into<String>, current_core_id: CoreId, ) -> Result<TraceContext, RuntimeError>
Creates a child span for another Core while preserving correlation.